[ostree] Rename libarchive write API to "export", matching command line



commit b08b1abccdb6f8614750b31f2e3dc572e7b7bc8a
Author: Colin Walters <walters verbum org>
Date:   Thu Feb 18 11:25:57 2016 -0500

    Rename libarchive write API to "export", matching command line
    
    I was going to add new API for importing, and it was really confusing
    that what I think of now as import and export both had "write" in the
    name.  It's just clearer to talk about the direction.
    
    At the same time, include `Export` in the options structure.
    
    This isn't an ABI break as the API isn't in a release.

 src/libostree/ostree-repo-libarchive.c |   18 +++++++-------
 src/libostree/ostree-repo.h            |   37 ++++++++++++++++---------------
 src/ostree/ot-builtin-export.c         |    6 ++--
 3 files changed, 31 insertions(+), 30 deletions(-)
---
diff --git a/src/libostree/ostree-repo-libarchive.c b/src/libostree/ostree-repo-libarchive.c
index 3b1b0b8..19fae75 100644
--- a/src/libostree/ostree-repo-libarchive.c
+++ b/src/libostree/ostree-repo-libarchive.c
@@ -362,7 +362,7 @@ ostree_repo_write_archive_to_mtree (OstreeRepo                *self,
 
 static gboolean
 file_to_archive_entry_common (GFile         *root,
-                              OstreeRepoArchiveOptions *opts,
+                              OstreeRepoExportArchiveOptions *opts,
                               GFile         *path,
                               GFileInfo  *file_info,
                               struct archive_entry *entry,
@@ -438,7 +438,7 @@ write_header_free_entry (struct archive *a,
 
 static gboolean
 write_directory_to_libarchive_recurse (OstreeRepo               *self,
-                                       OstreeRepoArchiveOptions *opts,
+                                       OstreeRepoExportArchiveOptions *opts,
                                        GFile                    *root,
                                        GFile                    *dir,
                                        struct archive           *a,
@@ -569,7 +569,7 @@ write_directory_to_libarchive_recurse (OstreeRepo               *self,
 #endif
 
 /**
- * ostree_repo_write_tree_to_archive:
+ * ostree_repo_export_tree_to_archive:
  * @self: An #OstreeRepo
  * @opts: Options controlling conversion
  * @root: An #OstreeRepoFile for the base directory
@@ -581,12 +581,12 @@ write_directory_to_libarchive_recurse (OstreeRepo               *self,
  * file structure to @mtree.
  */
 gboolean
-ostree_repo_write_tree_to_archive (OstreeRepo                *self,
-                                   OstreeRepoArchiveOptions *opts,
-                                   OstreeRepoFile            *root,
-                                   void                      *archive,
-                                   GCancellable             *cancellable,
-                                   GError                  **error)
+ostree_repo_export_tree_to_archive (OstreeRepo                *self,
+                                    OstreeRepoExportArchiveOptions *opts,
+                                    OstreeRepoFile            *root,
+                                    void                      *archive,
+                                    GCancellable             *cancellable,
+                                    GError                  **error)
 {
 #ifdef HAVE_LIBARCHIVE
   gboolean ret = FALSE;
diff --git a/src/ostree/ot-builtin-export.c b/src/ostree/ot-builtin-export.c
index 2d350b8..cccb50e 100644
--- a/src/ostree/ot-builtin-export.c
+++ b/src/ostree/ot-builtin-export.c
@@ -63,7 +63,7 @@ ostree_builtin_export (int argc, char **argv, GCancellable *cancellable, GError
   g_autofree char *commit = NULL;
   g_autoptr(GVariant) commit_data = NULL;
   struct archive *a;
-  OstreeRepoArchiveOptions opts = { 0, };
+  OstreeRepoExportArchiveOptions opts = { 0, };
 
   context = g_option_context_new ("COMMIT - Stream COMMIT to stdout in tar format");
 
@@ -124,8 +124,8 @@ ostree_builtin_export (int argc, char **argv, GCancellable *cancellable, GError
 
   opts.timestamp_secs = ostree_commit_get_timestamp (commit_data);
 
-  if (!ostree_repo_write_tree_to_archive (repo, &opts, (OstreeRepoFile*)root, a,
-                                          cancellable, error))
+  if (!ostree_repo_export_tree_to_archive (repo, &opts, (OstreeRepoFile*)root, a,
+                                           cancellable, error))
     goto out;
 
   if (archive_write_close (a) != ARCHIVE_OK)


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/libostree/ostree-repo.h b/src/libostree/ostree-repo.h
index 98794b9..3b1040a 100644
--- a/src/libostree/ostree-repo.h
+++ b/src/libostree/ostree-repo.h
@@ -441,12 +441,21 @@ gboolean      ostree_repo_write_dfd_to_mtree (OstreeRepo                 *self,
                                               GCancellable               *cancellable,
                                               GError                    **error);
 
+
+gboolean      ostree_repo_write_archive_to_mtree (OstreeRepo                   *self,
+                                                  GFile                        *archive,
+                                                  OstreeMutableTree            *mtree,
+                                                  OstreeRepoCommitModifier     *modifier,
+                                                  gboolean                      autocreate_parents,
+                                                  GCancellable                 *cancellable,
+                                                  GError                      **error);
+
 /**
- * OstreeRepoWriteArchiveOptions:
+ * OstreeRepoExportArchiveOptions:
  *
  * An extensible options structure controlling archive creation.  Ensure that
  * you have entirely zeroed the structure, then set just the desired
  * options.  This is used by ostree_repo_write_tree_to_archive().
  */
 typedef struct {
   guint disable_xattrs : 1;
@@ -456,22 +465,14 @@ typedef struct {
 
   guint unused_uint[8];
   gpointer unused_ptrs[8];
-} OstreeRepoArchiveOptions;
-
-gboolean      ostree_repo_write_archive_to_mtree (OstreeRepo                   *self,
-                                                  GFile                        *archive,
-                                                  OstreeMutableTree            *mtree,
-                                                  OstreeRepoCommitModifier     *modifier,
-                                                  gboolean                      autocreate_parents,
-                                                  GCancellable                 *cancellable,
-                                                  GError                      **error);
-
-gboolean ostree_repo_write_tree_to_archive (OstreeRepo                *self,
-                                            OstreeRepoArchiveOptions  *opts,
-                                            OstreeRepoFile            *root,
-                                            void                      *archive,  /* Really struct archive * 
*/
-                                            GCancellable             *cancellable,
-                                            GError                  **error);
+} OstreeRepoExportArchiveOptions;
+
+gboolean ostree_repo_export_tree_to_archive (OstreeRepo                *self,
+                                             OstreeRepoExportArchiveOptions  *opts,
+                                             OstreeRepoFile            *root,
+                                             void                      *archive,  /* Really struct archive * 
*/
+                                             GCancellable             *cancellable,
+                                             GError                  **error);
 
 gboolean      ostree_repo_write_mtree (OstreeRepo         *self,
                                        OstreeMutableTree  *mtree,
@@ -441,12 +441,21 @@ gboolean      ostree_repo_write_dfd_to_mtree (OstreeRepo                 *self,
  * An extensible options structure controlling archive creation.  Ensure that
  * you have entirely zeroed the structure, then set just the desired
- * options.  This is used by ostree_repo_write_tree_to_archive().
+ * options.  This is used by ostree_repo_export_tree_to_archive().
  */
 typedef struct {